Module forget

Module forget 

Forgetful functors for Var.

The Forget functor “forgets” operations created by the Var interface while preserving connectivity. Concretely, any operation labeled HasVar::var is mapped to a spider: An OpenHypergraph with the same interfaces, but whose hypergraph is a single node. If the operation has no sources and targets, it’s mapped to the empty OpenHypergraph.

Structs

Forget
Functor to replace operations labeled HasVar::var() with spiders, or the empty diagram.

Functions

forget
Replace operations labeled HasVar::var() with spiders, or the empty diagram.
forget_monogamous
Replace 1 → 1 operations labeled HasVar::var() with spiders, or the empty diagram.