pub struct Forget;Expand description
Functor to replace operations labeled HasVar::var() with spiders, or the empty diagram.
More precisely: if an operation labeled HasVar::var() has m sources and n targets, all labeled a,
then it will be replaced with a m → 1 ← n spider, with all nodes labeled a.
If m = 0 = n, the operation will be replaced by the empty diagram:
this corresponds to the Extra-special frobenius axiom, which says that 0 → 0 Frobenius maps are
the empty OpenHypergraph.
See p2 https://arxiv.org/pdf/1601.02307 - the “extra law”.