A Coffman-Graham-inspired layering algorithm.
Functions
- layer
- Compute a layering of an
OpenHypergraph: a mappinglayer : X → Kfrom operations to integers compatible with the partial ordering onXinduced by hypergraph structure. - layered_
operations - Given an
OpenHypergraph, compute a layering of its operations as a finite functionX → L, then return this as an array-of-arraysr.