Module layer

Module layer 

A Coffman-Graham-inspired layering algorithm.

Functions

layer
Compute a layering of an OpenHypergraph: a mapping layer : X → K from operations to integers compatible with the partial ordering on X induced by hypergraph structure.
layered_operations
Given an OpenHypergraph, compute a layering of its operations as a finite function X → L, then return this as an array-of-arrays r.